pairwisedist.pairwisedist
=========================

.. rubric:: Description

.. automodule:: pairwisedist.pairwisedist

.. currentmodule:: pairwisedist.pairwisedist




.. rubric:: Functions

.. autosummary::
    :toctree: .
    
    jackknife_distance
    
    pearson_distance
    
    spearman_distance
    
    yr1_distance
    
    ys1_distance
    

